@@ -33,14 +33,6 @@ import java.util.Map;
  */
 public class ResolvePathsResult<T>
 {
-    /**
-     * Source of the modulename 
-     */
-    public enum ModuleNameSource
-    {
-        FILENAME, MANIFEST, MODULEDESCRIPTOR
-    }
-    
     private JavaModuleDescriptor mainModuleDescriptor;
     
     /**
@@ -130,4 +122,15 @@ public class ResolvePathsResult<T>
     {
         return pathExceptions;
     }
+
+    @Override
+    public String toString() {
+        return "ResolvePathsResult{" + System.lineSeparator() +
+                "mainModuleDescriptor=" + mainModuleDescriptor + System.lineSeparator() +
+                ", pathElements=" + pathElements + System.lineSeparator() +
+                ", modulepathElements=" + modulepathElements + System.lineSeparator() +
+                ", classpathElements=" + classpathElements + System.lineSeparator() +
+                ", pathExceptions=" + pathExceptions + System.lineSeparator() +
+                '}';
+    }
 }
